@@ -1,4 +1,4 @@
-/* -*- mode: C -*- Time-stamp: "2010-12-19 17:46:14 jemarch"
+/* -*- mode: C -*- Time-stamp: "2011-01-30 20:30:55 jemarch"
  *
  *       File:         rec-int.c
  *       Date:         Thu Jul 15 18:23:26 2010
@@ -58,7 +58,7 @@ static int rec_int_check_record_unique (rec_rset_t rset, rec_record_t record,
                                         rec_buf_t errors);
 static int rec_int_check_record_prohibit (rec_rset_t rset, rec_record_t record,
                                           rec_buf_t errors);
-static void rec_int_merge_remote (rec_rset_t rset);
+static int rec_int_merge_remote (rec_rset_t rset, rec_buf_t errors);
 static bool rec_int_rec_type_p (char *str);
 
 /*
@@ -102,14 +102,25 @@ rec_int_check_rset (rec_db_t db,
   int res;
   rec_rset_elem_t rset_elem;
   rec_record_t record;
+  rec_record_t descriptor;
 
   res = 0;
 
-  if (remote_descriptor_p)
+  if (remote_descriptor_p
+      && (descriptor = rec_rset_descriptor (rset)))
     {
+      /* Make a backup of the record descriptor to restore it
+         later.  */
+      descriptor = rec_record_dup (descriptor);
+
       /* Fetch the remote descriptor, if any, and merge it with the
-         local descriptor.  */
-      rec_int_merge_remote (rset);
+         local descriptor.  If there is any error, stop and report
+         it.  */
+      res = rec_int_merge_remote (rset, errors);
+      if (res > 0)
+        {
+          return res;
+        }
     }
 
   if (check_descriptor_p)
@@ -135,6 +146,12 @@ rec_int_check_rset (rec_db_t db,
                                    errors);
     }
 
+  if (remote_descriptor_p)
+    {
+      /* Restore the original descriptor in the record set.  */
+      rec_rset_set_descriptor (rset, descriptor);
+    }
+
   return res;
 }
 
@@ -401,7 +418,7 @@ rec_int_check_record_unique (rec_rset_t rset,
                   > 1)
                 {
                   asprintf (&tmp,
-                             _("%s:%s: error: field '%s' shall be unique in this record\n"),
+                             _("%s:%s: error: field '%s' should be unique in this record\n"),
                              rec_record_source (record),
                              rec_record_location_str (record),
                              unique_field_str);
@@ -611,11 +628,16 @@ rec_int_check_descriptor (rec_rset_t rset,
   rec_field_name_t mandatory_fname;
   rec_field_name_t unique_fname;
   rec_field_name_t prohibit_fname;
+  rec_field_name_t auto_fname;
   char *field_value;
   rec_fex_t fex;
   char *tmp;
+  rec_field_name_t auto_field_name;
+  char *auto_field_name_str;
+  size_t i;
+  rec_type_reg_t type_reg;
+  rec_type_t type;
 
-  res = 0;
   descriptor = rec_rset_descriptor (rset);
   if (descriptor)
     {
@@ -626,6 +648,7 @@ rec_int_check_descriptor (rec_rset_t rset,
       mandatory_fname = rec_parse_field_name_str ("%mandatory:");
       unique_fname = rec_parse_field_name_str ("%unique:");
       prohibit_fname = rec_parse_field_name_str ("%prohibit:");
+      auto_fname = rec_parse_field_name_str ("%auto:");
 
       /* Check the type of the record set:
 
@@ -704,7 +727,8 @@ rec_int_check_descriptor (rec_rset_t rset,
             }
           else if (rec_field_name_equal_p (field_name, mandatory_fname)
                    || rec_field_name_equal_p (field_name, unique_fname)
-                   || rec_field_name_equal_p (field_name, prohibit_fname))
+                   || rec_field_name_equal_p (field_name, prohibit_fname)
+                   || rec_field_name_equal_p (field_name, auto_fname))
             {
               /* Check that the value of this field is a parseable
                  list of field names.  */
@@ -726,6 +750,37 @@ rec_int_check_descriptor (rec_rset_t rset,
                   res++;
                 }
             }
+          
+          if ((rec_field_name_equal_p (field_name, auto_fname))
+              && (fex = rec_fex_new (field_value, REC_FEX_SIMPLE)))
+            {
+              /* Check that the auto incremented fields have not been
+                 declared with a type other than 'int'. */
+              for (i = 0; i < rec_fex_size (fex); i++)
+                {
+                  auto_field_name = rec_fex_elem_field_name (rec_fex_get (fex, i));
+                  auto_field_name_str = rec_fex_elem_field_name_str (rec_fex_get (fex, i));
+                  type_reg = rec_rset_get_type_reg (rset);
+                  if (type_reg)
+                    {
+                      type = rec_type_reg_get (type_reg, auto_field_name);
+                      if ((!type) ||
+                          ! ((rec_type_kind (type) == REC_TYPE_INT)
+                             || (rec_type_kind (type) == REC_TYPE_RANGE)
+                             || (rec_type_kind (type) == REC_TYPE_DATE)))
+                        {
+                          asprintf (&tmp,
+                                    _("%s:%s: error: auto-incremented field %s shall be of type int, range or date\n"),
+                                    rec_record_source (descriptor),
+                                    rec_record_location_str (descriptor),
+                                    auto_field_name_str);
+                          rec_buf_puts (tmp, errors);
+                          free (tmp);
+                          res++;
+                        }
+                    }
+                }
+            }
         }
 
       /* Destroy names.  */
@@ -735,14 +790,17 @@ rec_int_check_descriptor (rec_rset_t rset,
       rec_field_name_destroy (mandatory_fname);
       rec_field_name_destroy (unique_fname);
       rec_field_name_destroy (prohibit_fname);
+      rec_field_name_destroy (auto_fname);
     }
 
   return res;
 }
 
-void
-rec_int_merge_remote (rec_rset_t rset)
+int
+rec_int_merge_remote (rec_rset_t rset,
+                      rec_buf_t errors)
 {
+  int res;
   rec_parser_t parser;
   rec_field_name_t rec_fname;
   rec_record_t descriptor;
@@ -759,6 +817,9 @@ rec_int_merge_remote (rec_rset_t rset)
   FILE *external_file;
   int tmpfile_des;
   char tmpfile_name[14];
+  char *tmp;
+
+  res = 0;
 
   rec_fname = rec_parse_field_name_str ("%rec:");
   tmpfile_name[0] = '\0';
@@ -803,10 +864,13 @@ rec_int_merge_remote (rec_rset_t rset)
               curl_easy_setopt (curl, CURLOPT_FAILONERROR, 1);
               if (curl_easy_perform (curl) != 0)
                 {
-                  /* Print a warning and return.  */
-                  fprintf (stderr,
-                           _("warning: could not fetch remote descriptor from url %s.\n"),
-                           rec_url);
+                  /* Error.  */
+                  asprintf (&tmp, _("%s:%s: error: could not fetch remote descriptor from url %s.\n"),
+                            rec_field_source (rec_field), rec_field_location_str (rec_field),
+                            rec_url);
+                  rec_buf_puts (tmp, errors);
+                  free (tmp);
+                  res++;
                   goto exit;
                 }
               curl_easy_cleanup (curl);
@@ -821,9 +885,12 @@ rec_int_merge_remote (rec_rset_t rset)
               external_file = fopen (rec_file, "r");
               if (!external_file)
                 {
-                  fprintf (stderr,
-                           _("warning: could not read external descriptor from file %s.\n"),
-                           rec_file);
+                  asprintf (&tmp, _("%s:%s: error: could not read external descriptor from file %s.\n"),
+                            rec_field_source (rec_field), rec_field_location_str (rec_field),
+                            rec_file);
+                  rec_buf_puts (tmp, errors);
+                  free (tmp);
+                  res++;
                   goto exit;
                 }
               rec_source = rec_file;
@@ -834,9 +901,12 @@ rec_int_merge_remote (rec_rset_t rset)
           parser = rec_parser_new (external_file, rec_source);
           if (!rec_parse_db (parser, &remote_db))
             {
-              fprintf (stderr,
-                       _("warning: %s does not contain valid rec data.\n"),
-                       rec_url);
+              asprintf (&tmp, _("%s:%s: error: %s does not contain valid rec data.\n"),
+                        rec_field_source (rec_field), rec_field_location_str (rec_field),
+                        rec_source);
+              rec_buf_puts (tmp, errors);
+              free (tmp);
+              res++;
               goto exit;
             }
           rec_parser_destroy (parser);
@@ -846,9 +916,12 @@ rec_int_merge_remote (rec_rset_t rset)
           remote_rset = rec_db_get_rset_by_type (remote_db, rec_type);
           if (!remote_rset)
             {
-              fprintf (stderr,
-                       _("warning: %s does not contain information for %s.\n"),
-                       rec_source, rec_type);
+              asprintf (&tmp, _("%s:%s: error: %s does not contain information for type %s.\n"),
+                        rec_field_source (rec_field), rec_field_location_str (rec_field),
+                        rec_source, rec_type);
+              rec_buf_puts (tmp, errors);
+              free (tmp);
+              res++;
               goto exit;
             }
           remote_descriptor = rec_rset_descriptor (remote_rset);
@@ -890,6 +963,8 @@ rec_int_merge_remote (rec_rset_t rset)
 
   free (rec_url);
   free (rec_file);
+
+  return res;
 }
 
 static bool
