@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2010 Jose E. Marchesi */
+/* Copyright (C) 2010,  2011 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -425,7 +425,7 @@ rec_type_new (char *str)
       {
         /* This point should not be reached.  */
         fprintf (stderr,
-                 _("rec-types: internal error: got REC_TYPE_NONE from rec_type_parse_type kind in rec_type_new.\n"));
+                 _("internal error: rec-types: got REC_TYPE_NONE from rec_type_parse_type_kind() in rec_type_new().\n"));
         exit (EXIT_FAILURE);
         break;
       }
@@ -760,6 +760,40 @@ rec_type_equal_p (rec_type_t type1,
   return ret;
 }
 
+int
+rec_type_min (rec_type_t type)
+{
+  int res;
+
+  if (type->kind != REC_TYPE_RANGE)
+    {
+      res = -1;
+    }
+  else
+    {
+      res = type->data.range[0];
+    }
+
+  return res;
+}
+
+int
+rec_type_max (rec_type_t type)
+{
+  int res;
+
+  if (type->kind != REC_TYPE_RANGE)
+    {
+      res = -1;
+    }
+  else
+    {
+      res = type->data.range[1];
+    }
+
+  return res;
+}
+
 /*
  * Private functions.
  */
@@ -1129,10 +1163,29 @@ rec_type_parse_enum (char *str, rec_type_t type)
   while (*p && (i < REC_ENUM_MAX_NAMES))
     {
       /* Skip blanks.  */
-      /* XXX and comments as well!.  */
       rec_skip_blanks (&p);
 
-      if (*p)
+
+      if (*p == '(')
+        {
+          /* Skip the comment.  */
+          p++;
+          while (*p && (*p != ')') && (*p != '('))
+            {
+              p++;
+            }
+          if (*p == ')')
+            {
+              p++;
+            }
+          else
+            {
+              /* Parse error: unterminated comment. */
+              p = NULL;
+              break;
+            }
+        }
+      else if (*p)
         {
           /* Parse an enum entry.  */
           if (!rec_parse_regexp (&p,
