@@ -2,7 +2,7 @@
 #
 # recfix.sh - System tests for recfix.
 #
-# Copyright (C) 2010 Jose E. Marchesi.
+# Copyright (C) 2010, 2011 Jose E. Marchesi.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -162,6 +162,98 @@ test_declare_input_file multiple-rec \
 bar: 10
 '
 
+test_declare_input_file enum-valid \
+'%rec: foo
+%type: bar enum
++ KEY1 (This is key 1)
++ KEY2 (This is key 2)
++ KEY3 (This is key 3)
+
+bar: KEY1
+
+bar: KEY2
+
+bar: KEY3
+'
+
+test_declare_input_file enum-invalid-1 \
+'%rec: foo
+%type: bar enum
++ KEY1 (This is key 1)
++ KEY2 ((This is key 2)
++ KEY3 (This is key 3)
+
+bar: KEY1
+
+bar: KEY2
+
+bar: KEY3
+'
+
+test_declare_input_file enum-invalid-2 \
+'%rec: foo
+%type: bar enum
++ KEY1 (This is key 1)
++ KEY2 (This is key 2))
++ KEY3 (This is key 3)
+
+bar: KEY1
+
+bar: KEY2
+
+bar: KEY3
+'
+
+test_declare_input_file prohibited-fields-ok \
+'%rec: foo
+%prohibit: banned
+
+foo: bar
+
+bar: baz
+'
+
+test_declare_input_file prohibited-fields \
+'%rec: foo
+%prohibit: banned1 banned2
+
+foo: bar
+banned1: foo
+
+bar: baz
+banned2: bar
+
+bar: foo
+'
+
+test_declare_input_file auto-int \
+'%rec: foo
+%type: myint int
+%auto: myint
+'
+
+test_declare_input_file auto-range \
+'%rec: foo
+%type: myrange range 0 10
+%auto: myrange
+'
+
+test_declare_input_file auto-date \
+'%rec: foo
+%type: mydate date
+%auto: mydate
+'
+
+test_declare_input_file auto-notype \
+'%rec: foo
+%auto: myint
+'
+
+test_declare_input_file auto-nofex \
+'%rec: foo
+%auto: this%is#not%a^ fex
+'
+
 #
 # Declare tests.
 #
@@ -242,6 +334,61 @@ test_tool recfix-multiple-rec-in-descriptor xfail \
           '' \
           multiple-rec
 
+test_tool recfix-enum-valid ok \
+          recfix \
+          '' \
+          enum-valid \
+          ''
+
+test_tool recfix-enum-invalid-1 xfail \
+          recfix \
+          '' \
+          enum-invalid-1
+
+test_tool recfix-enum-invalid-2 xfail \
+          recfix \
+          '' \
+          enum-invalid-2
+
+test_tool recfix-prohibited-fields-ok ok \
+          recfix \
+          '' \
+          prohibited-fields-ok \
+''
+
+test_tool recfix-prohibited-fields-fail xfail \
+          recfix \
+          '' \
+          prohibited-fields
+
+test_tool recfix-auto-int ok \
+          recfix \
+          '' \
+          auto-int \
+''
+
+test_tool recfix-auto-range ok \
+          recfix \
+          '' \
+          auto-range \
+''
+
+test_tool recfix-auto-date ok \
+          recfix \
+          '' \
+          auto-date \
+''
+
+test_tool recfix-auto-notype xfail \
+          recfix \
+          '' \
+          auto-notype
+
+test_tool recfix-auto-nofex xfail \
+          recfix \
+          '' \
+          auto-nofex
+
 #
 # Cleanup.
 #
