@@ -1,4 +1,4 @@
-/* -*- mode: C -*- Time-stamp: "2010-12-22 23:04:40 jemarch"
+/* -*- mode: C -*- Time-stamp: "2011-01-31 22:35:08 jemarch"
  *
  *       File:         recutl.c
  *       Date:         Thu Apr 22 17:30:48 2010
@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2010 Jose E. Marchesi */
+/* Copyright (C) 2010, 2011 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -129,7 +129,7 @@ recutl_print_version (void)
 Copyright (C) %s Jose E. Marchesi.\n\
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.\n\
 This is free software: you are free to change and redistribute it.\n\
-There is NO WARRANTY, to the extent permitted by law.\n"), "2010");
+There is NO WARRANTY, to the extent permitted by law.\n"), "2010, 2011");
 
   puts (_("\
 \n\
@@ -143,7 +143,7 @@ recutl_fatal (const char *fmt, ...)
 
   va_start (ap, fmt);
   fputs (program_name, stderr);
-  fputs (": error: ", stderr);
+  fputs (_(": error: "), stderr);
   vfprintf (stderr, fmt, ap);
   va_end (ap);
 
@@ -157,7 +157,7 @@ recutl_error (const char *fmt, ...)
 
   va_start (ap, fmt);
   fputs (program_name, stderr);
-  fputs (": error: ", stderr);
+  fputs (_(": error: "), stderr);
   vfprintf (stderr, fmt, ap);
   va_end (ap);
 }
@@ -169,7 +169,7 @@ recutl_warning (const char *fmt, ...)
 
   va_start (ap, fmt);
   fputs (program_name, stderr);
-  fputs (": warning: ", stderr);
+  fputs (_(": warning: "), stderr);
   vfprintf (stderr, fmt, ap);
   va_end (ap);
 }
@@ -326,6 +326,8 @@ recutl_write_db_to_file (rec_db_t db,
   char *tmp_file_name;
   rec_writer_t writer;
   int des;
+  struct stat st1;
+  int stat_result;
 
   if (!file_name)
     {
@@ -333,6 +335,9 @@ recutl_write_db_to_file (rec_db_t db,
     }
   else
     {
+      /* Record the original file attributes. */
+      stat_result = stat (file_name, &st1);
+
       /* Create a temporary file with the results. */
       tmp_file_name = xmalloc (100);
       strcpy (tmp_file_name, "recXXXXXX");
@@ -362,6 +367,12 @@ recutl_write_db_to_file (rec_db_t db,
           remove (tmp_file_name);
           recutl_fatal (_("renaming file %s to %s\n"), tmp_file_name, file_name);
         }
+
+      /* Restore the attributes of the original file. */
+      if (stat_result != -1)
+        {
+          chmod (file_name, st1.st_mode);
+        }
     }
 }
 
@@ -391,4 +402,31 @@ recutl_read_file (char *file_name)
   return result;
 }
 
+void
+recutl_check_integrity (rec_db_t db,
+                        bool verbose_p,
+                        bool external_p)
+{
+  rec_buf_t errors_buf;
+  char *errors_str;
+  size_t errors_str_size;
+
+  errors_buf = rec_buf_new (&errors_str, &errors_str_size);
+  if (rec_int_check_db (db, true, external_p, errors_buf) > 0)
+    {
+      rec_buf_close (errors_buf);
+      if (!verbose_p)
+        {
+          recutl_error (_("operation aborted due to integrity failures.\n"));
+          recutl_error (_("use --verbose to get a detailed report.\n"));
+        }
+      else
+        {
+          fprintf (stderr, "%s", errors_str);
+        }
+
+      recutl_fatal (_("use --force to skip the integrity check.\n"));
+    }
+}
+
 /* End of recutl.c */
