@@ -1,4 +1,4 @@
-/* -*- mode: C -*- Time-stamp: "2010-12-22 22:57:52 jemarch"
+/* -*- mode: C -*- Time-stamp: "2011-01-31 22:34:52 jemarch"
  *
  *       File:         recutl.h
  *       Date:         Thu Apr 22 17:29:52 2010
@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2010 Jose E. Marchesi */
+/* Copyright (C) 2010, 2011 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -179,6 +179,10 @@ void recutl_write_db_to_file (rec_db_t db, char *file_name);
 
 char *recutl_read_file (char *file_name);
 
+void recutl_check_integrity (rec_db_t db,
+                             bool verbose_p,
+                             bool external_p);
+
 #endif /* recutl.h */
 
 /* End of recutl.h */
